==> thunderbird_66.0~b1.orig.tar.xz: thunderbird-66.0/browser/components/newtab/prerendered/locales/lij/activity-stream-strings.js <==
// Note - this is a generated lij file.
window.gActivityStreamStrings = {
  "newtab_page_title": "Neuvo Feuggio",
  "header_top_sites": "I megio sciti",
  "header_highlights": "In evidensa",
  "header_recommended_by": "Consegiou da {provider}",
  "context_menu_button_sr": "Arvi into menû contesto pe {title}",
  "section_context_menu_button_sr": "Arvi into menû contesto pe-a seçion",
  "type_label_visited": "Vixitou",
  "type_label_bookmarked": "Azonto a-i segnalibbri",
  "type_label_recommended": "De tentensa",
  "type_label_pocket": "Sarvou in Pocket",
  "type_label_downloaded": "Descaregou",
  "menu_action_bookmark": "Azonzi a-i segnalibbri",
  "menu_action_remove_bookmark": "Scancella segnalibbro",
  "menu_action_open_new_window": "Arvi in neuvo barcon",
  "menu_action_open_private_window": "Arvi in neuvo barcon privou",
  "menu_action_dismiss": "Scancella",
  "menu_action_delete": "Scancella da-a stöia",
  "menu_action_pin": "Azonzi a-a bacheca",
  "menu_action_unpin": "Leva da bacheca",
  "confirm_history_delete_p1": "Te seguo de scancelâ tutte e ripetiçioin de sta pagina da stöia?",
  "confirm_history_delete_notice_p2": "Sta açion a no se peu anulâ.",
  "menu_action_save_to_pocket": "Sarva in Pocket",
  "menu_action_delete_pocket": "Scancella da Pocket",
  "menu_action_archive_pocket": "Archivia in Pocket",
  "menu_action_show_file_mac_os": "Fanni vedde in Finder",
  "menu_action_show_file_windows": "Arvi cartella",
  "menu_action_show_file_linux": "Arvi cartella",
  "menu_action_show_file_default": "Fanni vedde file",
  "menu_action_open_file": "Arvi file",
  "menu_action_copy_download_link": "Còpia indirisso òrigine",
  "menu_action_go_to_download_page": "Vanni a-a pagina de descaregamento",
  "menu_action_remove_download": "Scancella da-a stöia",
  "search_button": "Çerca",
  "search_header": "Riçerca {search_engine_name}",
  "search_web_placeholder": "Çerca inta Ræ",
  "section_disclaimer_topstories": "E stöie ciù interesanti do Web, seleçionæ in baze a quello che ti lezi. Pigiæ da Pocket, che oua o l'é parte de Mozilla.",
  "section_disclaimer_topstories_linktext": "Descòvri comme fonçionn-a.",
  "section_disclaimer_topstories_buttontext": "Va ben, ò capio",
  "prefs_home_header": "Pagina iniçiâ de Firefox",
  "prefs_home_description": "Çerni i contegnui che ti veu vedde inta pagina iniçiâ de Firefox.",
  "prefs_content_discovery_header": "Firefox Home",
  "prefs_content_discovery_description": "Content Discovery in Firefox Home allows you to discover high-quality, relevant articles from across the web.",
  "prefs_content_discovery_button": "Turn Off Content Discovery",
  "prefs_section_rows_option": "{num} riga;{num} righe",
  "prefs_search_header": "Çerca into Web",
  "prefs_topsites_description": "I sciti che ti vixiti de ciù",
  "prefs_topstories_description2": "I megio contegnui pigiæ in gio pe-a ræ, personalizæ pe ti",
  "prefs_topstories_options_sponsored_label": "Stöie sponsorizæ",
  "prefs_topstories_sponsored_learn_more": "Atre informaçioin",
  "prefs_highlights_description": "'Na seleçion di sciti che t'ê sarvou ò vixitou",
  "prefs_highlights_options_visited_label": "Pagine vixitæ",
  "prefs_highlights_options_download_label": "Urtimi descaregamenti",
  "prefs_highlights_options_pocket_label": "Pagine sarvæ in Pocket",
  "prefs_snippets_description": "Agiornamenti da Mozilla e Firefox",
  "settings_pane_button_label": "Personalizza a teu pagina Neuvo feuggio",
  "settings_pane_topsites_header": "I megio sciti",
  "settings_pane_highlights_header": "In evidensa",
  "settings_pane_highlights_options_bookmarks": "Segnalibbri",
  "settings_pane_snippets_header": "Snippet",
  "edit_topsites_button_text": "Cangia",
  "edit_topsites_edit_button": "Cangia sto scito",
  "topsites_form_add_header": "Neuvo scito prinçipâ",
  "topsites_form_edit_header": "Cangia scito prinçipâ",
  "topsites_form_title_label": "Titolo",
  "topsites_form_title_placeholder": "Scrivi 'n titolo",
  "topsites_form_url_label": "URL",
  "topsites_form_image_url_label": "URL da inmagine personalizâ",
  "topsites_form_url_placeholder": "Scrivi ò incòlla URL",
  "topsites_form_use_image_link": "Adeuvia inagine personalizâ…",
  "topsites_form_preview_button": "Anteprimma",
  "topsites_form_add_button": "Azonzi",
  "topsites_form_save_button": "Sarva",
  "topsites_form_cancel_button": "Anulla",
  "topsites_form_url_validation": "Serve 'na URL bonn-a",
  "topsites_form_image_validation": "Erô into caregamento de l'inmagine. Preuva 'n atra URL.",
  "pocket_read_more": "Argomenti popolari:",
  "pocket_read_even_more": "Amia atre stöie",
  "pocket_more_reccommendations": "Atri conseggi",
  "pocket_how_it_works": "Comme o fonçionn-a",
  "pocket_cta_button": "Piggite Pocket",
  "pocket_cta_text": "Sarva e stöie che te piaxan into Pocket, e carega torna a mente con letue che incantan.",
  "highlights_empty_state": "Iniçia a navegâ e, in sta seçion, saian mostræ articoli, video e atre pagine vixitæ de fresco ò azonti a-i segnalibbri.",
  "topstories_empty_state": "No gh'é atro. Contròlla ciù tardi se gh'é atre stöie da {provider}. No t'eu aspetâ? Seleçionn-a 'n argomento tra quelli ciù popolari pe descovrî atre notiçie interesanti da-o Web.",
  "manual_migration_explanation2": "Preuva Firefox con i segnalibbri, a stöia e-e paròlle segrete de 'n atro navegatô.",
  "manual_migration_cancel_button": "No graçie",
  "manual_migration_import_button": "Inpòrta oua",
  "error_fallback_default_info": "Ahime mi, gh'é quarche problema into caregamento de sto contegnuo.",
  "error_fallback_default_refresh_suggestion": "Agiorna pagina pe provâ torna.",
  "section_menu_action_remove_section": "Scancella seçion",
  "section_menu_action_collapse_section": "Conprimmi seçion",
  "section_menu_action_expand_section": "Espandi seçion",
  "section_menu_action_manage_section": "Gestisci seçion",
  "section_menu_action_manage_webext": "Gestisci estenscioin",
  "section_menu_action_add_topsite": "Azonzi scito prinçipâ",
  "section_menu_action_add_search_engine": "Azonzi motô de riçerca",
  "section_menu_action_move_up": "Mescia in sciù",
  "section_menu_action_move_down": "Mescia in zu",
  "section_menu_action_privacy_notice": "Informativa in sciâ privacy",
  "firstrun_title": "Pòrta Firefox con ti",
  "firstrun_content": "Repiggia i teu segnalibbri, stöia, poule segrete e atre inpostaçioin in sce tutti i teu dispoxitivi.",
  "firstrun_learn_more_link": "Saccine de ciù in sce l'account Firefox",
  "firstrun_form_header": "Scrivi a teu email",
  "firstrun_form_sub_header": "pe continoâ con Firefox Sync.",
  "firstrun_email_input_placeholder": "Email",
  "firstrun_invalid_input": "Serve 'na email bonn-a",
  "firstrun_extra_legal_links": "Se ti væ avanti t'ê d'acòrdio co-i {terms} e l'{privacy}.",
  "firstrun_terms_of_service": "Termini do serviçio",
  "firstrun_privacy_notice": "Informativa in sciâ privacy",
  "firstrun_continue_to_login": "Continoa",
  "firstrun_skip_login": "Sata sto passo",
  "context_menu_title": "Open menu",
  "pocket_learn_more": "Atre informaçioin"
};

==> thunderbird_68.5.0.orig.tar.xz: thunderbird-68.5.0/browser/components/newtab/prerendered/locales/lij/activity-stream-strings.js <==
// Note - this is a generated lij file.
window.gActivityStreamStrings = {
  "newtab_page_title": "Neuvo feuggio",
  "header_top_sites": "I megio sciti",
  "header_highlights": "In evidensa",
  "header_recommended_by": "Consegiou da {provider}",
  "context_menu_button_sr": "Arvi into menû contesto pe {title}",
  "section_context_menu_button_sr": "Arvi into menû contesto pe-a seçion",
  "type_label_visited": "Vixitou",
  "type_label_bookmarked": "Azonto a-i segnalibbri",
  "type_label_recommended": "De tentensa",
  "type_label_pocket": "Sarvou in Pocket",
  "type_label_downloaded": "Descaregou",
  "menu_action_bookmark": "Azonzi a-i segnalibbri",
  "menu_action_remove_bookmark": "Scancella segnalibbro",
  "menu_action_open_new_window": "Arvi in neuvo barcon",
  "menu_action_open_private_window": "Arvi in neuvo barcon privou",
  "menu_action_dismiss": "Scancella",
  "menu_action_delete": "Scancella da-a stöia",
  "menu_action_pin": "Azonzi a-a bacheca",
  "menu_action_unpin": "Leva da bacheca",
  "confirm_history_delete_p1": "Te seguo de scancelâ tutte e ripetiçioin de sta pagina da stöia?",
  "confirm_history_delete_notice_p2": "Sta açion a no se peu anulâ.",
  "menu_action_save_to_pocket": "Sarva in Pocket",
  "menu_action_delete_pocket": "Scancella da Pocket",
  "menu_action_archive_pocket": "Archivia in Pocket",
  "menu_action_show_file_mac_os": "Fanni vedde in Finder",
  "menu_action_show_file_windows": "Arvi cartella",
  "menu_action_show_file_linux": "Arvi cartella",
  "menu_action_show_file_default": "Mostra o schedaio",
  "menu_action_open_file": "Arvi schedaio",
  "menu_action_copy_download_link": "Còpia indirisso òrigine",
  "menu_action_go_to_download_page": "Vanni a-a pagina de descaregamento",
  "menu_action_remove_download": "Scancella da-a stöia",
  "search_button": "Çerca",
  "search_header": "Riçerca {search_engine_name}",
  "search_web_placeholder": "Çerca inta Ræ",
  "section_disclaimer_topstories": "E stöie ciù interesanti do Web, seleçionæ in baze a quello che ti lezi. Pigiæ da Pocket, che oua o l'é parte de Mozilla.",
  "section_disclaimer_topstories_linktext": "Descòvri comme fonçionn-a.",
  "section_disclaimer_topstories_buttontext": "Va ben, ò capio",
  "prefs_home_header": "Pagina iniçiâ de Firefox",
  "prefs_home_description": "Çerni i contegnui che ti veu vedde inta pagina iniçiâ de Firefox.",
  "prefs_content_discovery_description": "Content Discovery in Firefox Home allows you to discover high-quality, relevant articles from across the web.",
  "prefs_section_rows_option": "{num} riga;{num} righe",
  "prefs_search_header": "Çerca into Web",
  "prefs_topsites_description": "I sciti che ti vixiti de ciù",
  "prefs_topstories_description2": "I megio contegnui pigiæ in gio pe-a ræ, personalizæ pe ti",
  "prefs_topstories_options_sponsored_label": "Stöie sponsorizæ",
  "prefs_topstories_sponsored_learn_more": "Atre informaçioin",
  "prefs_highlights_description": "'Na seleçion di sciti che t'ê sarvou ò vixitou",
  "prefs_highlights_options_visited_label": "Pagine vixitæ",
  "prefs_highlights_options_download_label": "Urtimi descaregamenti",
  "prefs_highlights_options_pocket_label": "Pagine sarvæ in Pocket",
  "prefs_snippets_description": "Agiornamenti da Mozilla e Firefox",
  "settings_pane_button_label": "Personalizza a teu pagina Neuvo feuggio",
  "settings_pane_topsites_header": "I megio sciti",
  "settings_pane_highlights_header": "In evidensa",
  "settings_pane_highlights_options_bookmarks": "Segnalibbri",
  "settings_pane_snippets_header": "Snippet",
  "edit_topsites_button_text": "Cangia",
  "edit_topsites_edit_button": "Cangia sto scito",
  "topsites_form_add_header": "Neuvo scito prinçipâ",
  "topsites_form_edit_header": "Cangia scito prinçipâ",
  "topsites_form_title_label": "Titolo",
  "topsites_form_title_placeholder": "Scrivi 'n titolo",
  "topsites_form_url_label": "URL",
  "topsites_form_image_url_label": "URL da inmagine personalizâ",
  "topsites_form_url_placeholder": "Scrivi ò incòlla URL",
  "topsites_form_use_image_link": "Adeuvia inagine personalizâ…",
  "topsites_form_preview_button": "Anteprimma",
  "topsites_form_add_button": "Azonzi",
  "topsites_form_save_button": "Sarva",
  "topsites_form_cancel_button": "Anulla",
  "topsites_form_url_validation": "Serve 'na URL bonn-a",
  "topsites_form_image_validation": "Erô into caregamento de l'inmagine. Preuva 'n atra URL.",
  "pocket_read_more": "Argomenti popolari:",
  "pocket_read_even_more": "Amia atre stöie",
  "pocket_more_reccommendations": "Atri conseggi",
  "pocket_how_it_works": "Comme o fonçionn-a",
  "pocket_cta_button": "Piggite Pocket",
  "pocket_cta_text": "Sarva e stöie che te piaxan into Pocket, e carega torna a mente con letue che incantan.",
  "highlights_empty_state": "Iniçia a navegâ e, in sta seçion, saian mostræ articoli, video e atre pagine vixitæ de fresco ò azonti a-i segnalibbri.",
  "topstories_empty_state": "No gh'é atro. Contròlla ciù tardi se gh'é atre stöie da {provider}. No t'eu aspetâ? Seleçionn-a 'n argomento tra quelli ciù popolari pe descovrî atre notiçie interesanti da-o Web.",
  "error_fallback_default_info": "Ahime mi, gh'é quarche problema into caregamento de sto contegnuo.",
  "error_fallback_default_refresh_suggestion": "Agiorna pagina pe provâ torna.",
  "section_menu_action_remove_section": "Scancella seçion",
  "section_menu_action_collapse_section": "Conprimmi seçion",
  "section_menu_action_expand_section": "Espandi seçion",
  "section_menu_action_manage_section": "Gestisci seçion",
  "section_menu_action_manage_webext": "Gestisci estenscioin",
  "section_menu_action_add_topsite": "Azonzi scito prinçipâ",
  "section_menu_action_add_search_engine": "Azonzi motô de riçerca",
  "section_menu_action_move_up": "Mescia in sciù",
  "section_menu_action_move_down": "Mescia in zu",
  "section_menu_action_privacy_notice": "Informativa in sciâ privacy",
  "firstrun_title": "Pòrta Firefox con ti",
  "firstrun_content": "Repiggia i teu segnalibbri, stöia, poule segrete e atre inpostaçioin in sce tutti i teu dispoxitivi.",
  "firstrun_learn_more_link": "Saccine de ciù in sciô conto Firefox",
  "firstrun_form_header": "Scrivi a teu email",
  "firstrun_form_sub_header": "pe continoâ con Firefox Sync.",
  "firstrun_email_input_placeholder": "Email",
  "firstrun_invalid_input": "Serve 'na email bonn-a",
  "firstrun_extra_legal_links": "Se ti væ avanti t'ê d'acòrdio co-i {terms} e l'{privacy}.",
  "firstrun_terms_of_service": "Termini do serviçio",
  "firstrun_privacy_notice": "Informativa in sciâ privacy",
  "firstrun_continue_to_login": "Continoa",
  "firstrun_skip_login": "Sata sto passo",
  "context_menu_title": "Arvi menû"
};
